API Reference
=============

Leaching
--------

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/module-with-contents.rst

   prommis.leaching.leach_train
   prommis.leaching.leach_reactions
   prommis.leaching.leach_solids_properties
   prommis.leaching.leach_solution_properties

Roasting
--------

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/module-with-contents.rst

   prommis.roasting.ree_feed_roaster
   prommis.roasting.ree_oxalate_roaster

Solvent Extraction
------------------

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/module-with-contents.rst

   prommis.solvent_extraction.ree_aq_distribution
   prommis.solvent_extraction.ree_og_distribution
   prommis.solvent_extraction.solvent_extraction

Precipitate
-----------

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/module-with-contents.rst
   
   prommis.precipitate.precipitator
   prommis.precipitate.precipitate_liquid_properties
   prommis.precipitate.precipitate_solids_properties

Crusher
-------

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/module-with-contents.rst

   prommis.solid_handling.crusher
   prommis.solid_handling.crusher_solids_properties

Evaporation Ponds
-----------------

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/module-with-contents.rst
   
   prommis.evaporation_pond.evaporation_pond

Flowsheets
----------

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/module-with-contents.rst

   prommis.uky.uky_flowsheet

Nanofiltration
--------------

.. autosummary::
   :toctree: _autosummary
   :template: autosummary/module-with-contents.rst

   prommis.nanofiltration.diafiltration_properties
   prommis.nanofiltration.diafiltration
   prommis.nanofiltration.nf_brine_plot
   prommis.nanofiltration.nf_brine
